@@ -9,7 +9,7 @@ package Time::Monotonic;
 use Exporter 'import';
 our @EXPORT_OK = qw(monotonic_time);
 
-our $VERSION = 'v0.9.5';
+our $VERSION = 'v0.9.6';
 
 require XSLoader;
 XSLoader::load('Time::Monotonic', $VERSION);
@@ -26,6 +26,17 @@ sub is_monotonic {
     Time::Monotonic::monotonic_clock_is_monotonic();
 }
 
+sub new {
+    my ($class, $offset) = @_;
+    my $now = monotonic_time() + ($offset // 0);
+    bless \$now => ref $class || $class;
+}
+
+sub now {
+    my $self = shift;
+    return monotonic_time() - $$self;
+}
+
 1;
 __END__
 
@@ -42,6 +53,9 @@ Time::Monotonic - A clock source that only increments and never jumps
   die unless Time::Monotonic::is_monotonic();
   say "Backend API: ".Time::Monotonic::backend();
 
+  $oo = Time::Monotonic->new;
+  $oo->now;
+
 =head1 DESCRIPTION
 
 Time::Monotonic gives access to monotonic clocks on various platforms (Mac
@@ -88,6 +102,26 @@ Platform/OS/hardware combo.
 
 =back
 
+=head1 OO Interface
+
+Creating a new instance of Time::Monotonic stores the current monotonic
+counter value as a blessed scalar reference. Consecutive calls to
+C<< $instance->now >> returns the time difference since the moment of
+instantiation. This behavior is equivalent to L<Time::HiRes/tv_interval>.
+
+  my $t0 = Time::Monotonic->new;
+  my $t1 = $t0->now;
+
+The constructor also accepts an offset value (in fractional seconds), which
+will be added to the counter value.
+
+  my $t0 = Time::Monotonic->new($offset);
+  my $t1 = $t0->now;
+
+Dereferencing returns the initial value:
+
+  print "timer started at: ", $$t0;
+
 =head1 SEE ALSO
 
 L<Source Code Repository|https://github.com/caldwell/Time-Monotonic>
